@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2002 - 2022 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2002 - 2023 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
@@ -148,7 +148,13 @@ class VariableItem:
                 self.value = VariableItem.noOfItemsStr.format(length_code)
 
         if dtype != "str":
-            self.valueShort = self.value
+            if len(self.value) > 256:
+                self.valueShort = QCoreApplication.translate(
+                    "VariableItem", "<double click to show value>"
+                )
+            else:
+                self.valueShort = self.value[:256]
+
             self.tooltip = str(self.value)[:256]
             return
 
