@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2010 - 2022 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2010 - 2023 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
@@ -325,7 +325,7 @@ def retryAbort(parent, title, text, icon=Question, textFormat=Qt.TextFormat.Auto
 
 def okToClearData(parent, title, text, saveFunc, textFormat=Qt.TextFormat.AutoText):
     """
-    Function to show a model message box to ask for clearing the data.
+    Function to show a modal message box to ask for clearing the data.
 
     @param parent parent widget of the message box (QWidget)
     @param title caption of the message box (string)
@@ -335,16 +335,15 @@ def okToClearData(parent, title, text, saveFunc, textFormat=Qt.TextFormat.AutoTe
     @param textFormat format of the text (Qt.TextFormat)
     @return flag indicating that it is ok to clear the data (boolean)
     """
+    buttons = QMessageBox.StandardButton.Abort | QMessageBox.StandardButton.Discard
+    if saveFunc:
+        buttons |= QMessageBox.StandardButton.Save
     res = __messageBox(
         parent,
         title,
         text,
         QMessageBox.Icon.Warning,
-        (
-            QMessageBox.StandardButton.Abort
-            | QMessageBox.StandardButton.Discard
-            | QMessageBox.StandardButton.Save
-        ),
+        buttons,
         QMessageBox.StandardButton.Save,
         textFormat,
     )
