@@ -17,32 +17,7 @@ import semver
 
 from PyQt6.QtCore import QByteArray, QCoreApplication, QProcess, qVersion
 
-from eric7.SystemUtilities.DesktopUtilities import (  # __IGNORE_FLAKES_WARNING__
-    desktopName,
-    isGnomeDesktop,
-    isKdeDesktop,
-    isWaylandSession,
-    sessionType,
-)
-
-# TODO: remove these with release 23.4
-# imports from eric7.SystemUtilities are for backward compatibility
-from eric7.SystemUtilities.OSUtilities import (  # __IGNORE_FLAKES_WARNING__
-    isLinuxPlatform,
-    isMacPlatform,
-    isWindowsPlatform,
-)
-from eric7.SystemUtilities.PythonUtilities import (  # __IGNORE_FLAKES_WARNING__
-    getPythonExecutable,
-    getPythonLibraryDirectory,
-    getPythonScriptsDirectory,
-)
-from eric7.SystemUtilities.QtUtilities import (  # __IGNORE_FLAKES_WARNING__
-    getPyQt6ModulesDirectory,
-    getPyQtToolsPath,
-    getQtBinariesPath,
-    qVersionTuple,
-)
+from eric7.SystemUtilities import PythonUtilities
 
 try:
     from eric7.eric7config import getConfig
@@ -310,7 +285,7 @@ def getWebBrowserSupport():
 
     scriptPath = os.path.join(getConfig("ericDir"), "Tools", "webBrowserSupport.py")
     proc = QProcess()
-    proc.start(getPythonExecutable(), [scriptPath, qVersion()])
+    proc.start(PythonUtilities.getPythonExecutable(), [scriptPath, qVersion()])
     variant = (
         str(proc.readAllStandardOutput(), "utf-8", "replace").strip()
         if proc.waitForFinished(10000)
