@@ -117,6 +117,8 @@ class CircuitPythonUpdaterInterface(QObject):
         menu.addSeparator()
         menu.addAction(self.tr("Add Bundle"), self.__addBundle)
         menu.addAction(self.tr("Remove Bundles"), self.__removeBundle)
+        menu.addSeparator()
+        menu.addAction(self.tr("Show Local Cache Path"), self.__showCachePath)
 
     @pyqtSlot()
     def __aboutCircup(self):
@@ -655,6 +657,20 @@ class CircuitPythonUpdaterInterface(QObject):
         dlg = RequirementsDialog(devicePath=devicePath)
         dlg.exec()
 
+    @pyqtSlot()
+    def __showCachePath(self):
+        """
+        Private slot to show the path used by 'circup' to store the downloaded bundles.
+        """
+        EricMessageBox.information(
+            None,
+            self.tr("Show Local Cache Path"),
+            self.tr(
+                "<p><b>circup</b> stores the downloaded CircuitPython bundles in this"
+                " directory.</p><p>{0}</p>"
+            ).format(circup.DATA_DIR),
+        )
+
 
 def isCircupAvailable():
     """
