@@ -19,7 +19,9 @@ from PyQt6.QtWidgets import (
     QApplication,
     QDialog,
     QHBoxLayout,
+    QInputDialog,
     QLabel,
+    QLineEdit,
     QMenu,
     QSizePolicy,
     QTextEdit,
@@ -33,14 +35,19 @@ from eric7.EricGui.EricOverrideCursor import EricOverrideCursor, EricOverridenCu
 from eric7.EricWidgets import EricFileDialog, EricMessageBox
 from eric7.EricWidgets.EricApplication import ericApp
 from eric7.EricWidgets.EricListSelectionDialog import EricListSelectionDialog
+from eric7.EricWidgets.EricPlainTextDialog import EricPlainTextDialog
 from eric7.EricWidgets.EricProcessDialog import EricProcessDialog
 from eric7.EricWidgets.EricZoomWidget import EricZoomWidget
 from eric7.SystemUtilities import FileSystemUtilities, OSUtilities
 from eric7.UI.Info import BugAddress
 
-from . import Devices, UF2FlashDialog
+from . import ConvertToUF2Dialog, Devices, UF2FlashDialog
+from .BluetoothDialogs.BluetoothController import BluetoothController
+from .EthernetDialogs.EthernetController import EthernetController
+from .MicroPythonFileManager import MicroPythonFileManager
 from .MicroPythonFileManagerWidget import MicroPythonFileManagerWidget
 from .Ui_MicroPythonWidget import Ui_MicroPythonWidget
+from .WifiDialogs.WifiController import WifiController
 
 try:
     from .MicroPythonGraphWidget import MicroPythonGraphWidget
@@ -223,6 +230,15 @@ class MicroPythonWidget(QWidget, Ui_MicroPythonWidget):
 
         self.__ui = parent
 
+        self.__wifiController = WifiController(self, self)
+        self.__wifiMenu = None
+
+        self.__bluetoothController = BluetoothController(self, self)
+        self.__btMenu = None
+
+        self.__ethernetController = EthernetController(self, self)
+        self.__ethernetMenu = None
+
         self.__superMenu = QMenu(self)
         self.__superMenu.aboutToShow.connect(self.__aboutToShowSuperMenu)
 
@@ -266,6 +282,7 @@ class MicroPythonWidget(QWidget, Ui_MicroPythonWidget):
         self.__zoomWidget.valueChanged.connect(self.__doZoom)
         self.__currentZoom = 0
 
+        self.__fileManager = None
         self.__fileManagerWidget = None
         self.__chartWidget = None
 
@@ -618,6 +635,11 @@ class MicroPythonWidget(QWidget, Ui_MicroPythonWidget):
                 self.tr("Press to connect the selected device")
             )
 
+        if not connected:
+            for menu in (self.__wifiMenu, self.__btMenu, self.__ethernetMenu):
+                if menu and menu.isTearOffMenuVisible():
+                    menu.hideTearOffMenu()
+
     def isConnected(self):
         """
         Public method to get the MicroPython device connection state.
@@ -745,9 +767,10 @@ class MicroPythonWidget(QWidget, Ui_MicroPythonWidget):
             if pasteText:
                 pasteText = pasteText.replace("\n\r", "\r")
                 pasteText = pasteText.replace("\n", "\r")
-                self.__interface.isConnected() and self.__interface.write(
-                    pasteText.encode("utf-8")
-                )
+                if self.__interface.isConnected():
+                    self.__interface.write(b"\x05")
+                    self.__interface.write(pasteText.encode("utf-8"))
+                    self.__interface.write(b"\x04")
 
     def eventFilter(self, obj, evt):
         """
@@ -1115,6 +1138,15 @@ class MicroPythonWidget(QWidget, Ui_MicroPythonWidget):
         boardName = self.deviceTypeComboBox.currentData(self.DeviceBoardRole)
         return boardName
 
+    def getDevice(self):
+        """
+        Public method to get a reference to the current device.
+
+        @return reference to the current device
+        @rtype BaseDevice
+        """
+        return self.__device
+
     def getDeviceWorkspace(self):
         """
         Public method to get the workspace directory of the device.
@@ -1211,7 +1243,7 @@ class MicroPythonWidget(QWidget, Ui_MicroPythonWidget):
         """
         Private method to disconnect from the device.
         """
-        self.__device.setConnected(False)
+        self.__device and self.__device.setConnected(False)
         self.__interface.disconnectFromDevice()
         self.__setConnected(False)
 
@@ -1381,8 +1413,9 @@ class MicroPythonWidget(QWidget, Ui_MicroPythonWidget):
                 if not self.__interface.isConnected():
                     self.__connectToDevice()
                 if self.__connected:
+                    self.__fileManager = MicroPythonFileManager(self.__device, self)
                     self.__fileManagerWidget = MicroPythonFileManagerWidget(
-                        self.__device, self
+                        self.__fileManager, self
                     )
 
                     self.__ui.addSideWidget(
@@ -1400,6 +1433,8 @@ class MicroPythonWidget(QWidget, Ui_MicroPythonWidget):
             if self.__fileManagerWidget is not None:
                 self.__fileManagerWidget.stop()
                 self.__fileManagerWidget.deleteLater()
+            if self.__fileManager is not None:
+                self.__fileManager.deleteLater()
 
             if not self.replButton.isChecked() and not self.chartButton.isChecked():
                 self.__disconnectFromDevice()
@@ -1408,9 +1443,19 @@ class MicroPythonWidget(QWidget, Ui_MicroPythonWidget):
             self.__ui.removeSideWidget(self.__fileManagerWidget)
 
             self.__fileManagerWidget = None
+            self.__fileManager = None
 
         self.filesButton.setChecked(checked)
 
+    def getFileManager(self):
+        """
+        Public method to get a reference to the file manager interface.
+
+        @return reference to the file manager interface
+        @rtype MicroPythonFileManager
+        """
+        return self.__fileManager
+
     def shutdown(self):
         """
         Public method to perform some shutdown actions.
@@ -1429,6 +1474,13 @@ class MicroPythonWidget(QWidget, Ui_MicroPythonWidget):
         """
         self.__superMenu.clear()
 
+        if self.__device:
+            hasMip = self.__device.getDeviceData("mip")
+            hasUPip = self.__device.getDeviceData("upip")
+        else:
+            hasMip = False
+            hasUPip = False
+
         # prepare the download menu
         if self.__device:
             menuEntries = self.__device.getDownloadMenuEntries()
@@ -1444,6 +1496,38 @@ class MicroPythonWidget(QWidget, Ui_MicroPythonWidget):
             else:
                 downloadMenu = None
 
+        # prepare the WiFi menu
+        if self.__device and self.__connected and self.__device.getDeviceData("wifi"):
+            if self.__wifiMenu is not None:
+                self.__wifiMenu.deleteLater()
+            self.__wifiMenu = self.__wifiController.createMenu(self.__superMenu)
+        else:
+            self.__wifiMenu = None
+
+        # prepare the Bluetooth menu
+        if (
+            self.__device
+            and self.__connected
+            and self.__device.getDeviceData("bluetooth")
+        ):
+            if self.__btMenu is not None:
+                self.__btMenu.deleteLater()
+            self.__btMenu = self.__bluetoothController.createMenu(self.__superMenu)
+        else:
+            self.__btMenu = None
+
+        # prepare the Ethernet menu
+        if (
+            self.__device
+            and self.__connected
+            and self.__device.getDeviceData("ethernet")
+        ):
+            if self.__ethernetMenu is not None:
+                self.__ethernetMenu.deleteLater()
+            self.__ethernetMenu = self.__ethernetController.createMenu(self.__superMenu)
+        else:
+            self.__ethernetMenu = None
+
         # populate the super menu
         hasTime = self.__device.hasTimeCommands() if self.__device else False
 
@@ -1473,6 +1557,14 @@ class MicroPythonWidget(QWidget, Ui_MicroPythonWidget):
         self.__superMenu.addAction(
             self.tr("Show Builtin Modules"), self.__showBuiltinModules
         ).setEnabled(self.__connected)
+        if hasMip:
+            self.__superMenu.addAction(
+                self.tr("Install Package"), lambda: self.__installPackage("mip")
+            ).setEnabled(self.__connected)
+        elif hasUPip:
+            self.__superMenu.addAction(
+                self.tr("Install Packages"), lambda: self.__installPackage("upip")
+            ).setEnabled(self.__connected)
         self.__superMenu.addSeparator()
         if not OSUtilities.isWindowsPlatform():
             available = self.__mpyCrossAvailable()
@@ -1487,6 +1579,18 @@ class MicroPythonWidget(QWidget, Ui_MicroPythonWidget):
         if self.__device:
             self.__device.addDeviceMenuEntries(self.__superMenu)
             self.__superMenu.addSeparator()
+            if self.__wifiMenu is not None:
+                self.__superMenu.addMenu(self.__wifiMenu)
+            if self.__btMenu is not None:
+                self.__superMenu.addMenu(self.__btMenu)
+            if self.__ethernetMenu is not None:
+                self.__superMenu.addMenu(self.__ethernetMenu)
+            if (
+                self.__wifiMenu is not None
+                or self.__btMenu is not None
+                or self.__ethernetMenu is not None
+            ):
+                self.__superMenu.addSeparator()
             if downloadMenu is None:
                 # generic download action
                 self.__superMenu.addAction(
@@ -1500,6 +1604,7 @@ class MicroPythonWidget(QWidget, Ui_MicroPythonWidget):
                 self.tr("Show Documentation"), self.__showDocumentation
             ).setEnabled(self.__device.hasDocumentationUrl())
             self.__superMenu.addSeparator()
+        self.__superMenu.addAction(self.tr("Convert To UF2"), self.__convertToUF2)
         self.__superMenu.addAction(self.tr("Flash UF2 Device"), self.__flashUF2)
         self.__superMenu.addSeparator()
         self.__superMenu.addAction(
@@ -1593,7 +1698,7 @@ class MicroPythonWidget(QWidget, Ui_MicroPythonWidget):
             dlg = BoardDataDialog(boardInfo)
             dlg.exec()
         except Exception as exc:
-            self.__showError("getBoardInformation()", str(exc))
+            self.showError("getBoardInformation()", str(exc))
 
     @pyqtSlot()
     def __synchronizeTime(self, quiet=False):
@@ -1623,7 +1728,7 @@ class MicroPythonWidget(QWidget, Ui_MicroPythonWidget):
                             + self.__getDeviceTime(),
                         )
             except Exception as exc:
-                self.__showError("syncTime()", str(exc))
+                self.showError("syncTime()", str(exc))
 
     def __getDeviceTime(self):
         """
@@ -1650,7 +1755,7 @@ class MicroPythonWidget(QWidget, Ui_MicroPythonWidget):
                         dateTimeString.strip()
                     )
             except Exception as exc:
-                self.__showError("getTime()", str(exc))
+                self.showError("getTime()", str(exc))
                 return ""
         else:
             return ""
@@ -1727,11 +1832,11 @@ class MicroPythonWidget(QWidget, Ui_MicroPythonWidget):
                     ).format(localdate, localtime, deviceDateTimeString.strip()),
                 )
         except Exception as exc:
-            self.__showError("getTime()", str(exc))
+            self.showError("getTime()", str(exc))
 
-    def __showError(self, method, error):
+    def showError(self, method, error):
         """
-        Private method to show some error message.
+        Public method to show some error message.
 
         @param method name of the method the error occured in
         @type str
@@ -1977,6 +2082,14 @@ class MicroPythonWidget(QWidget, Ui_MicroPythonWidget):
         dlg = UF2FlashDialog.UF2FlashDialog()
         dlg.exec()
 
+    @pyqtSlot()
+    def __convertToUF2(self):
+        """
+        Private slot to convert a non-UF2 MicroPython firmware file to UF2.
+        """
+        dlg = ConvertToUF2Dialog.ConvertToUF2Dialog()
+        dlg.exec()
+
     @pyqtSlot()
     def __showBuiltinModules(self):
         """
@@ -1994,4 +2107,55 @@ class MicroPythonWidget(QWidget, Ui_MicroPythonWidget):
                 )
                 dlg.show()
             except Exception as exc:
-                self.__showError("getModules()", str(exc))
+                self.showError("getModules()", str(exc))
+
+    @pyqtSlot()
+    def __installPackage(self, method):
+        """
+        Private slot to install packages using the given method.
+
+        @param method package management method to be used (one of 'upip' or 'mip')
+        @type str
+        @exception ValueError raised to indicate an unsupported package management
+            method
+        """
+        from .MipPackageDialog import MipPackageDialog
+
+        if method not in ("mip", "upip"):
+            raise ValueError(
+                "Unsupported method given. Expected 'mip' or 'upip' but got {0}."
+            ).format(method)
+
+        if method == "mip":
+            title = self.tr("Install Package")
+            dlg = MipPackageDialog(self)
+            if dlg.exec() == QDialog.DialogCode.Accepted:
+                package, version, mpy = dlg.getData()
+                with EricOverrideCursor():
+                    out, err = self.__device.mipInstall(package, version, mpy)
+            else:
+                return
+        elif method == "upip":
+            title = self.tr("Install Packages")
+            packagesStr, ok = QInputDialog.getText(
+                self,
+                self.tr("Install Packages"),
+                self.tr("Enter the packages to be installed separated by whitespace:"),
+                QLineEdit.EchoMode.Normal,
+            )
+            if ok and packagesStr:
+                packages = packagesStr.split()
+                with EricOverrideCursor():
+                    out, err = self.__device.upipInstall(packages)
+            else:
+                return
+        else:
+            return
+
+        if err:
+            self.showError(title, err.decode("utf-8"))
+        if out:
+            dlg = EricPlainTextDialog(
+                title=title, text=out.decode("utf-8"), parent=self
+            )
+            dlg.exec()
