@@ -1047,21 +1047,12 @@ class Pip(QObject):
     ## License handling methods below
     #######################################################################
 
-    def getLicenses(self, envName, localPackages=True, usersite=False, summary=False):
+    def getLicenses(self, envName):
         """
         Public method to get the licenses per package for a given environment.
 
         @param envName name of the environment to get the licenses for
         @type str
-        @param localPackages flag indicating to get the licenses for local
-            packages only
-        @type bool
-        @param usersite flag indicating to get the licenses for packages
-            installed in user-site directory only
-        @type bool
-        @param summary flag indicating to get a summary listing (defaults to
-            False)
-        @type bool (optional)
         @return list of dictionaries containing the license and version per
             package
         @rtype dict
@@ -1080,12 +1071,6 @@ class Pip(QObject):
                     "--with-urls",
                     "--with-description",
                 ]
-                if localPackages:
-                    args.append("--local-only")
-                if usersite:
-                    args.append("--user-only")
-                if summary:
-                    args.append("--summary-by-license")
 
                 proc = QProcess()
                 proc.start(interpreter, args)
@@ -1099,24 +1084,3 @@ class Pip(QObject):
                         licenses = json.loads(output)
 
         return licenses
-
-    def getLicensesSummary(self, envName, localPackages=True, usersite=False):
-        """
-        Public method to get a summary of licenses found in a given
-        environment.
-
-        @param envName name of the environment to get the licenses summary for
-        @type str
-        @param localPackages flag indicating to get the licenses summary for
-            local packages only
-        @type bool
-        @param usersite flag indicating to get the licenses summary for
-            packages installed in user-site directory only
-        @type bool
-        @return list of dictionaries containing the license and the count of
-            packages
-        @rtype dict
-        """
-        return self.getLicenses(
-            envName, localPackages=localPackages, usersite=usersite, summary=True
-        )
