@@ -377,6 +377,18 @@ class PipPackagesWidget(QWidget, Ui_PipPackagesWidget):
             if bool(itm.text(PipPackagesWidget.AvailableVersionColumn))
         ]
 
+    def __allPackageNames(self):
+        """
+        Private method to get a list of all package names.
+
+        @return list of all package names
+        @rtype list of str
+        """
+        packages = []
+        for index in range(self.packagesList.topLevelItemCount()):
+            packages.append(self.packagesList.topLevelItem(index).text(0))
+        return packages
+
     def __allUpdateableItems(self):
         """
         Private method to get a list of all items that can be updated.
@@ -638,7 +650,21 @@ class PipPackagesWidget(QWidget, Ui_PipPackagesWidget):
             else:
                 packageVersion = item.text(PipPackagesWidget.InstalledVersionColumn)
 
-        self.__showPackageDetails(packageName, packageVersion, upgradable=upgradable)
+        vulnerabilities = (
+            item.data(
+                PipPackagesWidget.VulnerabilityColumn,
+                PipPackagesWidget.VulnerabilityRole,
+            )
+            if bool(item.text(PipPackagesWidget.VulnerabilityColumn))
+            else []
+        )
+
+        self.__showPackageDetails(
+            packageName,
+            packageVersion,
+            vulnerabilities=vulnerabilities,
+            upgradable=upgradable,
+        )
 
     @pyqtSlot(bool)
     def on_verboseCheckBox_clicked(self, checked):
@@ -766,8 +792,20 @@ class PipPackagesWidget(QWidget, Ui_PipPackagesWidget):
             else:
                 packageVersion = item.text(PipPackagesWidget.InstalledVersionColumn)
 
+            vulnerabilities = (
+                item.data(
+                    PipPackagesWidget.VulnerabilityColumn,
+                    PipPackagesWidget.VulnerabilityRole,
+                )
+                if bool(item.text(PipPackagesWidget.VulnerabilityColumn))
+                else []
+            )
+
             self.__showPackageDetails(
-                packageName, packageVersion, upgradable=upgradable
+                packageName,
+                packageVersion,
+                vulnerabilities=vulnerabilities,
+                upgradable=upgradable,
             )
 
     #######################################################################
@@ -1107,7 +1145,12 @@ class PipPackagesWidget(QWidget, Ui_PipPackagesWidget):
         self.__showPackageDetails(packageName, packageVersion, installable=True)
 
     def __showPackageDetails(
-        self, packageName, packageVersion, upgradable=False, installable=False
+        self,
+        packageName,
+        packageVersion,
+        vulnerabilities=None,
+        upgradable=False,
+        installable=False,
     ):
         """
         Private method to populate the package details dialog.
@@ -1116,6 +1159,8 @@ class PipPackagesWidget(QWidget, Ui_PipPackagesWidget):
         @type str
         @param packageVersion version of the package
         @type str
+        @param vulnerabilities list of known vulnerabilities (defaults to None)
+        @type list (optional)
         @param upgradable flag indicating that the package may be upgraded
             (defaults to False)
         @type bool (optional)
@@ -1145,7 +1190,10 @@ class PipPackagesWidget(QWidget, Ui_PipPackagesWidget):
                 self.__packageDetailsDialog.close()
 
             self.__packageDetailsDialog = PipPackageDetailsDialog(
-                packageData, buttonsMode=buttonsMode, parent=self
+                packageData,
+                vulnerabilities=vulnerabilities,
+                buttonsMode=buttonsMode,
+                parent=self,
             )
             self.__packageDetailsDialog.show()
         else:
@@ -1948,21 +1996,10 @@ class PipPackagesWidget(QWidget, Ui_PipPackagesWidget):
         from .PipLicensesDialog import PipLicensesDialog
 
         environment = self.environmentsComboBox.currentText()
-        localPackages = (
-            self.localDepCheckBox.isChecked()
-            if self.viewToggleButton.isChecked()
-            else self.localCheckBox.isChecked()
-        )
-        usersite = (
-            self.userDepCheckBox.isChecked()
-            if self.viewToggleButton.isChecked()
-            else self.userCheckBox.isChecked()
-        )
         dlg = PipLicensesDialog(
             self.__pip,
             environment,
-            localPackages=localPackages,
-            usersite=usersite,
+            packages=self.__allPackageNames(),
             parent=self,
         )
         dlg.exec()
