@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2003 - 2022 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2003 - 2023 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
@@ -23,6 +23,7 @@ from PyQt6.QtWidgets import (
 from eric7 import Utilities
 from eric7.EricGui import EricPixmapCache
 from eric7.EricWidgets.EricApplication import ericApp
+from eric7.SystemUtilities import FileSystemUtilities
 
 from .Ui_SyntaxCheckerDialog import Ui_SyntaxCheckerDialog
 
@@ -71,6 +72,7 @@ class SyntaxCheckerDialog(QDialog, Ui_SyntaxCheckerDialog):
 
         self.__fileList = []
         self.__project = None
+        self.__arguments = ()
         self.filterFrame.setVisible(False)
 
         self.checkProgress.setVisible(False)
@@ -157,6 +159,15 @@ class SyntaxCheckerDialog(QDialog, Ui_SyntaxCheckerDialog):
         itm.setData(0, self.errorRole, error)
         itm.setData(0, self.warningRole, isWarning)
 
+    def setArguments(self, args):
+        """
+        Public method to set additional arguments to be used by the syntax check.
+
+        @param args tuple containing the additional arguments
+        @type tuple of Any
+        """
+        self.__arguments = args
+
     def prepare(self, fileList, project):
         """
         Public method to prepare the dialog with a list of filenames.
@@ -178,7 +189,11 @@ class SyntaxCheckerDialog(QDialog, Ui_SyntaxCheckerDialog):
         self.__data = self.__project.getData("CHECKERSPARMS", "SyntaxChecker")
         if self.__data is None or "ExcludeFiles" not in self.__data:
             self.__data = {"ExcludeFiles": ""}
+        if "AdditionalBuiltins" not in self.__data:
+            self.__data["AdditionalBuiltins"] = ""
+
         self.excludeFilesEdit.setText(self.__data["ExcludeFiles"])
+        self.builtinsEdit.setText(self.__data["AdditionalBuiltins"])
 
     def startForBrowser(self, fn):
         """
@@ -190,9 +205,15 @@ class SyntaxCheckerDialog(QDialog, Ui_SyntaxCheckerDialog):
         if isinstance(fn, list):
             files = fn
         elif os.path.isdir(fn):
-            files = []
-            for ext in self.syntaxCheckService.getExtensions():
-                files.extend(Utilities.direntries(fn, True, "*{0}".format(ext), 0))
+            files = FileSystemUtilities.direntries(
+                fn,
+                filesonly=True,
+                pattern=[
+                    "*{0}".format(ext)
+                    for ext in self.syntaxCheckService.getExtensions()
+                ],
+                followsymlinks=False,
+            )
         else:
             files = [fn]
 
@@ -207,7 +228,11 @@ class SyntaxCheckerDialog(QDialog, Ui_SyntaxCheckerDialog):
             self.__data = self.__project.getData("CHECKERSPARMS", "SyntaxChecker")
             if self.__data is None or "ExcludeFiles" not in self.__data:
                 self.__data = {"ExcludeFiles": ""}
+            if "AdditionalBuiltins" not in self.__data:
+                self.__data["AdditionalBuiltins"] = ""
+
             self.excludeFilesEdit.setText(self.__data["ExcludeFiles"])
+            self.builtinsEdit.setText(self.__data["AdditionalBuiltins"])
 
             self.on_startButton_clicked()  # press the start button
 
@@ -247,7 +272,7 @@ class SyntaxCheckerDialog(QDialog, Ui_SyntaxCheckerDialog):
                 self.files = []
                 for ext in self.syntaxCheckService.getExtensions():
                     self.files.extend(
-                        Utilities.direntries(fn, True, "*{0}".format(ext), 0)
+                        FileSystemUtilities.direntries(fn, True, "*{0}".format(ext), 0)
                     )
             else:
                 self.files = [fn]
@@ -317,7 +342,9 @@ class SyntaxCheckerDialog(QDialog, Ui_SyntaxCheckerDialog):
                 return
 
         self.__finished = False
-        self.syntaxCheckService.syntaxCheck(None, self.filename, self.source)
+        self.syntaxCheckService.syntaxCheck(
+            None, self.filename, self.source, *self.__arguments
+        )
 
     def checkBatch(self):
         """
@@ -348,7 +375,7 @@ class SyntaxCheckerDialog(QDialog, Ui_SyntaxCheckerDialog):
                 )
                 continue
 
-            argumentsList.append((filename, source))
+            argumentsList.append((filename, source, *self.__arguments))
 
         # reset the progress bar to the checked files
         self.checkProgress.setValue(self.progress)
@@ -495,11 +522,9 @@ class SyntaxCheckerDialog(QDialog, Ui_SyntaxCheckerDialog):
         fileList = self.__fileList[:]
 
         filterString = self.excludeFilesEdit.text()
-        if (
-            "ExcludeFiles" not in self.__data
-            or filterString != self.__data["ExcludeFiles"]
-        ):
-            self.__data["ExcludeFiles"] = filterString
+        self.__data["ExcludeFiles"] = filterString
+        self.__data["AdditionalBuiltins"] = self.builtinsEdit.text().strip()
+        if self.__data != self.__project.getData("CHECKERSPARMS", "SyntaxChecker"):
             self.__project.setData("CHECKERSPARMS", "SyntaxChecker", self.__data)
         filterList = [f.strip() for f in filterString.split(",") if f.strip()]
         if filterList:
@@ -509,6 +534,7 @@ class SyntaxCheckerDialog(QDialog, Ui_SyntaxCheckerDialog):
         self.resultList.clear()
         self.noResults = True
         self.cancelled = False
+        self.setArguments((self.__data["AdditionalBuiltins"].split(),))
         self.start(fileList)
 
     def on_resultList_itemActivated(self, itm, col):
