@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2007 - 2022 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2007 - 2023 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
@@ -151,7 +151,9 @@ class SyntaxCheckerPlugin(QObject):
         """
         Private method to determine the syntax check options.
 
-        @return state of checkFlakes and ignoreStarImportWarnings (bool, bool)
+        @return tuple containing a flag indicating to perform a pyflakes check and
+            a flag indicating to ignore star import warnings
+        @rtype tuple of (bool, bool)
         """
         checkFlakes = Preferences.getFlakes("IncludeInSyntaxCheck")
         ignoreStarImportWarnings = Preferences.getFlakes("IgnoreStarImportWarnings")
@@ -402,9 +404,20 @@ class SyntaxCheckerPlugin(QObject):
             SyntaxCheckerDialog,
         )
 
+        project = ericApp().getObject("Project")
         editor = ericApp().getObject("ViewManager").activeWindow()
         if editor is not None:
             self.__editorSyntaxCheckerDialog = SyntaxCheckerDialog()
+            if editor.isPy3File():
+                self.__editorSyntaxCheckerDialog.setArguments(
+                    (
+                        project.getData("CHECKERSPARMS", "SyntaxChecker", {}).get(
+                            "AdditionalBuiltins", []
+                        ),
+                    )
+                    if editor.isProjectFile()
+                    else (Preferences.getFlakes("AdditionalBuiltins"),)
+                )
             self.__editorSyntaxCheckerDialog.show()
             if editor.isJavascriptFile():
                 unnamed = "Unnamed.js"
