@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2002 - 2022 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2002 - 2023 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
@@ -36,9 +36,10 @@ from eric7.EricGui import EricPixmapCache
 from eric7.EricWidgets.EricApplication import ericApp
 from eric7.EricWidgets.EricLed import EricLed
 from eric7.EricWidgets.EricTabWidget import EricTabWidget, EricWheelTabBar
-from eric7.Globals import getConfig, isMacPlatform
+from eric7.Globals import getConfig
 from eric7.QScintilla.Editor import Editor
 from eric7.QScintilla.EditorAssembly import EditorAssembly
+from eric7.SystemUtilities import OSUtilities
 from eric7.ViewManager.ViewManager import ViewManager
 
 
@@ -188,7 +189,7 @@ class TabWidget(EricTabWidget):
 
         self.setUsesScrollButtons(True)
         self.setElideMode(Qt.TextElideMode.ElideNone)
-        if isMacPlatform():
+        if OSUtilities.isMacPlatform():
             self.setDocumentMode(True)
 
         self.__tabBar.tabMoveRequested.connect(self.moveTab)
@@ -487,7 +488,7 @@ class TabWidget(EricTabWidget):
             maxFileNameChars = Preferences.getUI("TabViewManagerFilenameLength")
             if len(txt) > maxFileNameChars:
                 txt = "...{0}".format(txt[-maxFileNameChars:])
-            if editor.isReadOnly():
+            if editor.checkReadOnly():
                 txt = self.tr("{0} (ro)").format(txt)
 
             assembly = editor.parent()
@@ -1051,7 +1052,7 @@ class Tabview(ViewManager):
                 txt = ericApp().getObject("Project").getRelativePath(fn)
             if len(txt) > self.maxFileNameChars:
                 txt = "...{0}".format(txt[-self.maxFileNameChars :])
-            if not os.access(fn, os.W_OK):
+            if editor.checkReadOnly():
                 txt = self.tr("{0} (ro)").format(txt)
             if addNext:
                 index = self.currentTabWidget.currentIndex() + 1
@@ -1106,7 +1107,7 @@ class Tabview(ViewManager):
                 txt = ericApp().getObject("Project").getRelativePath(fn)
             if len(txt) > self.maxFileNameChars:
                 txt = "...{0}".format(txt[-self.maxFileNameChars :])
-            if not os.access(fn, os.W_OK):
+            if editor.checkReadOnly():
                 txt = self.tr("{0} (ro)").format(txt)
             nindex = tabWidget.insertWidget(index, win, txt)
             tabWidget.setTabToolTip(nindex, fn)
@@ -1497,7 +1498,7 @@ class Tabview(ViewManager):
                             txt = ericApp().getObject("Project").getRelativePath(fn)
                         if len(txt) > self.maxFileNameChars:
                             txt = "...{0}".format(txt[-self.maxFileNameChars :])
-                        if not os.access(fn, os.W_OK):
+                        if editor.checkReadOnly():
                             txt = self.tr("{0} (ro)").format(txt)
                         tabWidget.setTabText(index, txt)
 
