@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2002 - 2022 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2002 - 2023 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
@@ -114,6 +114,7 @@ class ProjectOthersBrowser(ProjectBaseBrowser):
         self.svgFile.connect(projectBrowser.svgFile)
         self.umlFile.connect(projectBrowser.umlFile)
         self.binaryFile.connect(projectBrowser.binaryFile)
+        self.pdfFile.connect(projectBrowser.pdfFile)
 
     def getIcon(self):
         """
@@ -137,6 +138,9 @@ class ProjectOthersBrowser(ProjectBaseBrowser):
         self.openInEditorAct = self.menu.addAction(
             self.tr("Open in Editor"), self._openFileInEditor
         )
+        self.openInPdfViewerAct = self.menu.addAction(
+            self.tr("Open in PDF Viewer"), self._openPdfViewer
+        )
         self.menu.addSeparator()
         self.mimeTypeAct = self.menu.addAction(
             self.tr("Show Mime-Type"), self.__showMimeType
@@ -260,6 +264,7 @@ class ProjectOthersBrowser(ProjectBaseBrowser):
                     if isinstance(itm, ProjectBrowserFileItem):
                         self.editPixmapAct.setVisible(itm.isPixmapFile())
                         self.openInEditorAct.setVisible(itm.isSvgFile())
+                        self.openInPdfViewerAct.setVisible(itm.isPdfFile())
                         self.mimeTypeAct.setVisible(True)
                         self.menu.popup(self.mapToGlobal(coord))
                     elif isinstance(itm, ProjectBrowserDirectoryItem):
@@ -347,6 +352,16 @@ class ProjectOthersBrowser(ProjectBaseBrowser):
             if isinstance(itm, ProjectBrowserFileItem):
                 self.binaryFile.emit(itm.fileName())
 
+    def _openPdfViewer(self):
+        """
+        Protected slot to handle the open in PDF viewer popup menu entry.
+        """
+        itmList = self.getSelectedItems()
+
+        for itm in itmList:
+            if isinstance(itm, ProjectBrowserFileItem) and itm.isPdfFile():
+                self.pdfFile.emit(itm.fileName())
+
     def _openItem(self):
         """
         Protected slot to handle the open popup menu entry.
@@ -355,7 +370,9 @@ class ProjectOthersBrowser(ProjectBaseBrowser):
 
         for itm in itmList:
             if isinstance(itm, ProjectBrowserFileItem):
-                if itm.isSvgFile():
+                if itm.isPdfFile():
+                    self.pdfFile.emit(itm.fileName())
+                elif itm.isSvgFile():
                     self.svgFile.emit(itm.fileName())
                 elif itm.isPixmapFile():
                     self.pixmapFile.emit(itm.fileName())
@@ -390,9 +407,7 @@ class ProjectOthersBrowser(ProjectBaseBrowser):
                 EricMessageBox.warning(
                     self,
                     self.tr("Show Mime-Type"),
-                    self.tr(
-                        """The mime type of the file could not be""" """ determined."""
-                    ),
+                    self.tr("""The mime type of the file could not be determined."""),
                 )
             elif mimetype.split("/")[0] == "text":
                 EricMessageBox.information(
@@ -508,7 +523,7 @@ class ProjectOthersBrowser(ProjectBaseBrowser):
         dlg = DeleteFilesConfirmationDialog(
             self.parent(),
             self.tr("Delete files/directories"),
-            self.tr("Do you really want to delete these entries from the" " project?"),
+            self.tr("Do you really want to delete these entries from the project?"),
             names,
         )
 
