@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2004 - 2022 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2004 - 2023 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
@@ -75,7 +75,6 @@ class QuickFindFileDialog(QWidget, Ui_QuickFindFile):
         @rtype bool
         """
         if event.type() == QEvent.Type.KeyPress:
-
             # Anywhere in the dialog, make hitting escape cancel it
             if event.key() == Qt.Key.Key_Escape:
                 self.close()
@@ -190,7 +189,7 @@ class QuickFindFileDialog(QWidget, Ui_QuickFindFile):
                 possible.append(record)
 
         ordered = []
-        for (_, in_order, name) in possible:
+        for _, in_order, name in possible:
             try:
                 age = os.stat(os.path.join(self.project.ppath, name)).st_mtime
             except OSError:
