@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2022 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2022 - 2023 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
@@ -340,7 +340,7 @@ class TestResultsModel(QAbstractItemModel):
         testResultsToBeAdded = []
 
         for testResult in testResults:
-            for (index, currentResult) in enumerate(self.__testResults):
+            for index, currentResult in enumerate(self.__testResults):
                 if currentResult.id == testResult.id:
                     self.__testResults[index] = testResult
                     if minIndex is None:
