@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2006 - 2022 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2006 - 2023 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
@@ -18,10 +18,11 @@ from PyQt6.QtCore import PYQT_VERSION_STR, QProcess, QSettings, qVersion
 from PyQt6.QtGui import QCursor
 from PyQt6.QtWidgets import QApplication, QDialog, QMenu, QSystemTrayIcon
 
-from eric7 import Globals, Preferences, Utilities
+from eric7 import Globals, Preferences
 from eric7.EricGui import EricPixmapCache
 from eric7.EricWidgets import EricMessageBox
 from eric7.EricWidgets.EricApplication import ericApp
+from eric7.SystemUtilities import DesktopUtilities, FileSystemUtilities, PythonUtilities
 from eric7.UI.Info import Program, Version
 
 
@@ -138,6 +139,11 @@ class TrayStarter(QSystemTrayIcon):
             self.tr("Icon Editor"),
             self.__startIconEditor,
         )
+        self.__menu.addAction(
+            EricPixmapCache.getIcon("ericPdf"),
+            self.tr("PDF Viewer"),
+            self.__startPdfViewer,
+        )
         self.__menu.addSeparator()
 
         self.__menu.addAction(
@@ -303,14 +309,14 @@ class TrayStarter(QSystemTrayIcon):
 
         args = []
         args.append(applPath)
-        args.append("--config={0}".format(Utilities.getConfigDir()))
+        args.append("--config={0}".format(Globals.getConfigDir()))
         if self.settingsDir:
             args.append("--settings={0}".format(self.settingsDir))
         for arg in applArgs:
             args.append(arg)
 
         if not os.path.isfile(applPath) or not proc.startDetached(
-            Globals.getPythonExecutable(), args
+            PythonUtilities.getPythonExecutable(), args
         ):
             EricMessageBox.critical(
                 self,
@@ -460,6 +466,12 @@ class TrayStarter(QSystemTrayIcon):
         """
         self.__startProc("eric7_shell.py")
 
+    def __startPdfViewer(self):
+        """
+        Private slot to start the eric PDF Viewer window.
+        """
+        self.__startProc("eric7_pdf.py")
+
     def __showRecentProjectsMenu(self):
         """
         Private method to set up the recent projects menu.
@@ -474,7 +486,7 @@ class TrayStarter(QSystemTrayIcon):
             formatStr = "&{0:d}. {1}" if idx < 10 else "{0:d}. {1}"
             act = self.recentProjectsMenu.addAction(
                 formatStr.format(
-                    idx, Utilities.compactPath(rp, self.maxMenuFilePathLen)
+                    idx, FileSystemUtilities.compactPath(rp, self.maxMenuFilePathLen)
                 )
             )
             act.setData(rp)
@@ -493,7 +505,7 @@ class TrayStarter(QSystemTrayIcon):
             formatStr = "&{0:d}. {1}" if idx < 10 else "{0:d}. {1}"
             act = self.recentMultiProjectsMenu.addAction(
                 formatStr.format(
-                    idx, Utilities.compactPath(rmp, self.maxMenuFilePathLen)
+                    idx, FileSystemUtilities.compactPath(rmp, self.maxMenuFilePathLen)
                 )
             )
             act.setData(rmp)
@@ -512,7 +524,7 @@ class TrayStarter(QSystemTrayIcon):
             formatStr = "&{0:d}. {1}" if idx < 10 else "{0:d}. {1}"
             act = self.recentFilesMenu.addAction(
                 formatStr.format(
-                    idx, Utilities.compactPath(rf, self.maxMenuFilePathLen)
+                    idx, FileSystemUtilities.compactPath(rf, self.maxMenuFilePathLen)
                 )
             )
             act.setData(rf)
@@ -580,7 +592,7 @@ class TrayStarter(QSystemTrayIcon):
         except AttributeError:
             sip_version_str = "sip version not available"
 
-        versionText = self.tr("""<h3>Version Numbers</h3>""" """<table>""")
+        versionText = self.tr("""<h3>Version Numbers</h3><table>""")
 
         # Python version
         versionText += """<tr><td><b>Python</b></td><td>{0}</td></tr>""".format(
@@ -626,8 +638,8 @@ class TrayStarter(QSystemTrayIcon):
         )
 
         # desktop and session type
-        desktop = Globals.desktopName()
-        session = Globals.sessionType()
+        desktop = DesktopUtilities.desktopName()
+        session = DesktopUtilities.sessionType()
         if desktop or session:
             versionText += "<tr><td></td><td></td></tr>"
             if desktop:
