@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2014 - 2022 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2014 - 2023 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
@@ -29,8 +29,9 @@ from PyQt6.QtWidgets import (
     QWidget,
 )
 
-from eric7 import Preferences, Utilities
+from eric7 import Preferences
 from eric7.EricWidgets.EricApplication import ericApp
+from eric7.SystemUtilities import FileSystemUtilities
 
 
 class PreviewerHTML(QWidget):
@@ -157,7 +158,7 @@ class PreviewerHTML(QWidget):
         self.jsCheckBox.setChecked(enable)
 
         settings = self.previewView.settings()
-        settings.setAttribute(settings.JavascriptEnabled, enable)
+        settings.setAttribute(settings.WebAttribute.JavascriptEnabled, enable)
 
         self.processEditor()
 
@@ -254,8 +255,8 @@ class PreviewerHTML(QWidget):
         @param rootPath path of the web site root
         @type str
         """
-        self.__previewedPath = Utilities.normcasepath(
-            Utilities.fromNativeSeparators(filePath)
+        self.__previewedPath = FileSystemUtilities.normcasepath(
+            FileSystemUtilities.fromNativeSeparators(filePath)
         )
         self.__saveScrollBarPositions()
         self.previewView.page().loadFinished.connect(self.__restoreScrollBarPositions)
@@ -552,9 +553,9 @@ class PreviewProcessingThread(QThread):
                 break
 
             if incMatch.group(1) == "virtual":
-                incFile = Utilities.normjoinpath(docRoot, incMatch.group(2))
+                incFile = FileSystemUtilities.normjoinpath(docRoot, incMatch.group(2))
             elif incMatch.group(1) == "file":
-                incFile = Utilities.normjoinpath(baseDir, incMatch.group(2))
+                incFile = FileSystemUtilities.normjoinpath(baseDir, incMatch.group(2))
             else:
                 incFile = ""
             if os.path.exists(incFile):
@@ -585,7 +586,7 @@ class PreviewProcessingThread(QThread):
         if not root:
             return txt
 
-        root = Utilities.fromNativeSeparators(root)
+        root = FileSystemUtilities.fromNativeSeparators(root)
         if not root.endswith("/"):
             root += "/"
         rootLen = len(root)
@@ -868,7 +869,7 @@ class PreviewProcessingThread(QThread):
                 """<html xmlns="http://www.w3.org/1999/xhtml">\n"""
             )
         elif htmlFormat == "html5":
-            head = """<!DOCTYPE html>\n""" """<html lang="EN">\n"""
+            head = """<!DOCTYPE html>\n<html lang="EN">\n"""
         else:
             head = '<html lang="EN">\n'
         head += """<head>\n"""
