@@ -34,77 +34,7 @@ from PyQt6.QtCore import (
 
 from eric7 import Preferences
 from eric7.EricWidgets.EricApplication import ericApp
-
-# TODO: remove these with release 23.4
-# imports from eric7.SystemUtilities are for backward compatibility
-from eric7.Globals import (  # __IGNORE_FLAKES_WARNING__
-    desktopName,
-    getConfig,
-    getConfigDir,
-    getPythonExecutable,
-    getPythonLibraryDirectory,
-    getPythonScriptsDirectory,
-    sessionType,
-    setConfigDir,
-    toBool,
-)
-from eric7.SystemUtilities import DesktopUtilities
-from eric7.SystemUtilities.FileSystemUtilities import (  # __IGNORE_FLAKES_WARNING__
-    absolutePath,
-    absoluteUniversalPath,
-    compactPath,
-    direntries,
-    findVolume,
-    fromNativeSeparators,
-    getDirs,
-    getExecutablePath,
-    getExecutablePaths,
-    getWindowsExecutablePath,
-    isDrive,
-    isExecutable,
-    isinpath,
-    joinext,
-    normabsjoinpath,
-    normcaseabspath,
-    normcasepath,
-    normjoinpath,
-    relativeUniversalPath,
-    samefilepath,
-    samepath,
-    splitPath,
-    startswithPath,
-    toNativeSeparators,
-)
-from eric7.SystemUtilities.OSUtilities import (  # __IGNORE_FLAKES_WARNING__
-    getEnvironmentEntry,
-    hasEnvironmentEntry,
-    getHomeDir,
-    getUserName,
-    getRealName,
-    isLinuxPlatform,
-    isMacPlatform,
-    isWindowsPlatform,
-    win32_getRealName,
-    win32_GetUserName,
-    win32_Kill,
-)
-from eric7.SystemUtilities.PythonUtilities import (  # __IGNORE_FLAKES_WARNING__
-    determinePythonVersion,
-    getPythonLibPath,
-    getPythonVersion,
-)
-from eric7.SystemUtilities.QtUtilities import (  # __IGNORE_FLAKES_WARNING__
-    checkPyside,
-    generatePyQtToolPath,
-    generatePySideToolPath,
-    generateQtToolName,
-    getPyQt6ModulesDirectory,
-    getPyQtToolsPath,
-    getQtBinariesPath,
-    getQtMacBundle,
-    prepareQtMacBundle,
-    qVersionTuple,
-)
+from eric7.SystemUtilities import DesktopUtilities, OSUtilities
 from eric7.UI.Info import Program, Version
 
 
@@ -1014,7 +944,7 @@ def getPercentReplacement(code):
         return fn
     elif code in ["H", "%H"]:
         # home directory
-        return getHomeDir()
+        return OSUtilities.getHomeDir()
     elif code in ["L", "%L"]:
         # line of the cursor of the current editor
         aw = ericApp().getObject("ViewManager").activeWindow()
@@ -1039,7 +969,7 @@ def getPercentReplacement(code):
         return text
     elif code in ["U", "%U"]:
         # username
-        un = getUserName()
+        un = OSUtilities.getUserName()
         if un is None:
             return code
         else:
@@ -1207,7 +1137,7 @@ def generateDistroInfo(linesep="\n"):
     @rtype str
     """
     info = []
-    if isLinuxPlatform():
+    if OSUtilities.isLinuxPlatform():
         releaseList = glob.glob("/etc/*-release")
         if releaseList:
             info.append("Distribution Info:")
