@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2010 - 2022 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2010 - 2023 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
@@ -19,10 +19,11 @@ from PyQt6.QtCore import (
 from PyQt6.QtGui import QCursor, QKeySequence, QShortcut
 from PyQt6.QtWidgets import QApplication, QDialog, QFileIconProvider, QMenu, QStyle
 
-from eric7 import Globals, Preferences
+from eric7 import Preferences
 from eric7.EricGui import EricPixmapCache
 from eric7.EricWidgets import EricMessageBox
 from eric7.EricWidgets.EricApplication import ericApp
+from eric7.SystemUtilities import OSUtilities
 from eric7.Utilities.AutoSaver import AutoSaver
 from eric7.WebBrowser.WebBrowserWindow import WebBrowserWindow
 
@@ -104,7 +105,7 @@ class DownloadManager(QDialog, Ui_DownloadManager):
         if selectedRowsCount == 1:
             row = self.downloadsView.selectionModel().selectedRows()[0].row()
             itm = self.__downloads[row]
-            if itm.downloadedSuccessfully():
+            if itm.exists():
                 menu.addAction(
                     EricPixmapCache.getIcon("open"),
                     self.tr("Open"),
@@ -290,6 +291,9 @@ class DownloadManager(QDialog, Ui_DownloadManager):
         """
         self.__startUpdateTimer()
 
+        for itm in self.__downloads:
+            itm.updateButtonsAndLabels()
+
         super().show()
         self.activateWindow()
         self.raise_()
@@ -390,7 +394,6 @@ class DownloadManager(QDialog, Ui_DownloadManager):
             DownloadManager.RemoveNever,
             DownloadManager.RemoveSuccessFullDownload,
         ):
-
             if policy == self.removePolicy():
                 return
 
@@ -504,7 +507,7 @@ class DownloadManager(QDialog, Ui_DownloadManager):
             self.__stopUpdateTimer()
             self.infoLabel.clear()
             self.setWindowTitle(self.tr("Download Manager"))
-            if Globals.isWindowsPlatform():
+            if OSUtilities.isWindowsPlatform():
                 self.__taskbarButton().progress().hide()
 
             if Preferences.getWebBrowser("DownloadManagerAutoClose"):
@@ -559,7 +562,7 @@ class DownloadManager(QDialog, Ui_DownloadManager):
         @return reference to the task bar button
         @rtype QWinTaskbarButton or None
         """
-        if Globals.isWindowsPlatform():
+        if OSUtilities.isWindowsPlatform():
             from PyQt6.QtWinExtras import QWinTaskbarButton  # __IGNORE_WARNING_I10__
 
             if self.__winTaskbarButton is None:
@@ -581,7 +584,7 @@ class DownloadManager(QDialog, Ui_DownloadManager):
                 self.__stopUpdateTimer()
                 self.infoLabel.clear()
                 self.setWindowTitle(self.tr("Download Manager"))
-                if Globals.isWindowsPlatform():
+                if OSUtilities.isWindowsPlatform():
                     self.__taskbarButton().progress().hide()
             else:
                 progresses = []
@@ -623,7 +626,7 @@ class DownloadManager(QDialog, Ui_DownloadManager):
                     )
                     self.setWindowTitle(self.tr("{0}% - Download Manager"))
 
-                if Globals.isWindowsPlatform():
+                if OSUtilities.isWindowsPlatform():
                     self.__taskbarButton().progress().show()
                     self.__taskbarButton().progress().setValue(progress)
 
