@@ -132,7 +132,7 @@ def version():
         """\n"""
         """Copyright (c) 2003-2023 Detlev Offenbach"""
         """ <detlev@die-offenbachs.de>\n"""
-        """This is free software; see the LICENSE.GPL3 for copying"""
+        """This is free software; see LICENSE.txt for copying"""
         """ conditions.\n"""
         """There is NO warranty; not even for MERCHANTABILITY or FITNESS"""
         """ FOR A\n"""
@@ -421,6 +421,7 @@ def main():
                     continue
 
                 try:
+                    print("Processing", file)
                     module = ModuleParser.readModule(
                         file,
                         basename=basename,
@@ -435,6 +436,11 @@ def main():
                 except ImportError as v:
                     sys.stderr.write("{0} error: {1}\n".format(file, v))
                     continue
+                except Exception as ex:
+                    sys.stderr.write(
+                        "{0} error while parsing: {1}\n".format(file, str(ex))
+                    )
+                    raise
 
                 f = FileSystemUtilities.joinext(
                     os.path.join(outputDir, moduleDocument.name()), ".html"
@@ -458,9 +464,19 @@ def main():
                         out.write(doc)
                 except OSError as v:
                     sys.stderr.write("{0} error: {1}\n".format(file, v[1]))
+                except Exception as ex:
+                    sys.stderr.write(
+                        "{0} error while writing: {1}\n".format(file, str(ex))
+                    )
+                    raise
                 else:
                     sys.stdout.write("{0} ok\n".format(f))
 
+                sys.stdout.flush()
+                sys.stderr.flush()
+
+    sys.stdout.write("code documentation generated")
+
     sys.stdout.flush()
     sys.stderr.flush()
 
